@@ -3,7 +3,7 @@
  *
  * GKrellM LongRun Plugin
  * Initial work by: (c) 2001 Nozomi Sato (nozomi@palette.plala.or.jp)
- * Copyright (c) 2001-2002 Masaharu FUJITA
+ * Copyright (c) 2001-2003 Masaharu FUJITA
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,13 +25,26 @@
  *	     http://fjts.org/~m/Soft/GKrelLongRun/index_e.html (in English)
  */
 
-#include <gkrellm/gkrellm.h>
+#if defined(__Linux__)
+#define _XOPEN_SOURCE 500
+#endif
+
+#include <gkrellm2/gkrellm.h>
 #include <unistd.h>
 #include <utime.h>
 #include <dirent.h>
 
 #include "interface.h"
 
+#define VERSION "2.0.4"
+
+#if defined(__FreeBSD__)
+#include "if_freebsd.c"
+#endif
+#if defined(__Linux__)
+#include "if_linux.c"
+#endif
+
 extern gint x_label_position();
 
 #define GKRELLONGRUN "GKrelLongRun"
@@ -105,12 +118,7 @@ gkrellongrun_menu_factory()
 	GtkItemFactory *factory;
 	GtkAccelGroup *accel = gtk_accel_group_new();
 
-#if ((VERSION_MAJOR>1)||(VERSION_MAJOR==1 && VERSION_MINOR==1 && VERSION_REV>3)||(VERSION_MAJOR==1 && VERSION_MINOR>1))
 	gtk_window_add_accel_group(GTK_WINDOW(gkrellm_get_top_window()), accel);
-#else
-	gtk_window_add_accel_group(GTK_WINDOW(top_window), accel);
-#endif
-
 	factory = gtk_item_factory_new(GTK_TYPE_MENU, "<Main>", accel);
 	size = get_gkrellongrun_itemfactory_size();
 	gtk_item_factory_create_items(factory, size,
@@ -122,7 +130,6 @@ gkrellongrun_menu_factory()
 static void
 format_chart_text(gchar *buf, gint size)
 {
-	Chart *cp = longrun.gkchart.chart;
 	gchar c, *s;
 	gint len;
 
@@ -160,7 +167,7 @@ draw_chart_extra()
 	gkrellm_draw_chart_text(longrun.gkchart.chart, chart_style_id, buf);
 }
 
-static void draw_chart(Chart *chart)
+static void draw_chart(GkrellmChart *chart)
 {
 	gkrellm_draw_chartdata(chart);
 	if (longrun.gkchart.draw_extra_info)
@@ -179,7 +186,8 @@ gkrellongrun_chart_expose_event( GtkWidget *widget, GdkEventExpose *event )
 		pixmap = longrun.gkchart.chart->panel->pixmap;
 
 	if ( pixmap ) {
-		gdk_draw_pixmap(widget->window, GK.draw1_GC, pixmap,
+		gdk_draw_pixmap(widget->window, 
+                widget->style->fg_gc[GTK_WIDGET_STATE (widget)], pixmap,
 		event->area.x, event->area.y, event->area.x, event->area.y,
 		event->area.width, event->area.height);
 	}
@@ -201,7 +209,7 @@ gkrellongrun_expose_event( GtkWidget *widget, GdkEventExpose *event )
 
 	if ( pixmap ) {	
 		gdk_draw_pixmap( widget->window,
-			GK.draw1_GC, pixmap,
+			widget->style->fg_gc[GTK_WIDGET_STATE (widget)], pixmap,
 			event->area.x, event->area.y, event->area.x,
 			event->area.y, event->area.width, event->area.height );
 		return FALSE;
@@ -244,11 +252,12 @@ gkrellongrun_button_press(GtkWidget *widget, GdkEventButton *event,
 }
 
 static void
-create_gkrellongrun_parts(GtkWidget *vbox, gint first, Style *style, gint type)
+create_gkrellongrun_parts(GtkWidget *vbox, gint first,
+                          GkrellmStyle *style, gint type)
 {
-	Panel *panel;
-	Decal *decal;
-	TextStyle *textstyle;
+	GkrellmPanel *panel;
+	GkrellmDecal *decal;
+	GkrellmTextstyle *textstyle;
 
 	if ( first )
 		longrun.parts[type].panel = gkrellm_panel_new0();
@@ -256,7 +265,7 @@ create_gkrellongrun_parts(GtkWidget *vbox, gint first, Style *style, gint type)
 	if ( type == Meter ) {
 		longrun.parts[type].krell = gkrellm_create_krell(
 					longrun.parts[type].panel,
-					gkrellm_krell_meter_image(
+					gkrellm_krell_meter_piximage(
 						meter_style_id), style );
 
 		gkrellm_update_krell(longrun.parts[type].panel,
@@ -267,7 +276,7 @@ create_gkrellongrun_parts(GtkWidget *vbox, gint first, Style *style, gint type)
 	if ( type == Slider ) {
 		longrun.parts[type].krell = gkrellm_create_krell(
 					longrun.parts[type].panel,
-					gkrellm_krell_slider_image(),
+					gkrellm_krell_slider_piximage(),
 					gkrellm_krell_slider_style());
 		longrun.parts[type].krell->y0 =
 			(longrun.parts[type].panel->h - 
@@ -288,9 +297,9 @@ create_gkrellongrun_parts(GtkWidget *vbox, gint first, Style *style, gint type)
 			"M8", longrun.parts[type].panel->textstyle, style,
 			-1, -1, -1 );
 
-	gkrellm_configure_panel( longrun.parts[type].panel, NULL, style );
-	gkrellm_create_panel( vbox, longrun.parts[type].panel,
-			gkrellm_bg_meter_image(meter_style_id) );
+	gkrellm_panel_configure( longrun.parts[type].panel, NULL, style );
+	gkrellm_panel_create( vbox, longrun.monitor,
+			 longrun.parts[type].panel );
 
 	panel = longrun.parts[type].panel;
 	decal = longrun.parts[type].decal;
@@ -302,13 +311,13 @@ create_gkrellongrun_parts(GtkWidget *vbox, gint first, Style *style, gint type)
 				gdk_string_width( textstyle->font,
 					longrun.parts[type].label ), 0 );
 
-	if ( longrun.parts[type].enable )
-		gkrellm_monitor_height_adjust( panel->h );
-	else
+	if ( ! longrun.parts[type].enable ) {
+		gkrellm_monitor_height_adjust(-panel->h);
 		gtk_widget_hide( panel->hbox );
+	}
 
 	gkrellm_draw_decal_text( panel, decal, longrun.parts[type].label, -1 );
-	gkrellm_draw_layers( panel );
+	gkrellm_draw_panel_layers( panel );
 
 	if ( first ) {
 		gtk_signal_connect( GTK_OBJECT(panel->drawing_area),
@@ -326,20 +335,18 @@ create_gkrellongrun_parts(GtkWidget *vbox, gint first, Style *style, gint type)
 static void
 create_gkrellongrun_chart(GtkWidget *vbox, gint first)
 {
-	Style *style;
-	Krell *k;
-	ChartData *cd;
+	GkrellmStyle *style;
+	GkrellmKrell *k;
+	GkrellmChartdata *cd;
   
 	if ( first ) {
 		longrun.gkchart.chart = gkrellm_chart_new0();
 		longrun.gkchart.chart->panel = gkrellm_panel_new0();
 	}
   
-	longrun.gkchart.display = GDK_WINDOW_XDISPLAY(vbox->window);
-	longrun.gkchart.window = GDK_WINDOW_XWINDOW(vbox->window);
 	style = gkrellm_panel_style(chart_style_id);
   
-	gkrellm_chart_create(vbox, longrun.gkchart.monitor,
+	gkrellm_chart_create(vbox, longrun.monitor,
 		longrun.gkchart.chart, &longrun.gkchart.chart_config);
 	cd = gkrellm_add_default_chartdata(longrun.gkchart.chart, "Percentage");
 	gkrellm_monotonic_chartdata(cd, FALSE);
@@ -352,20 +359,20 @@ create_gkrellongrun_chart(GtkWidget *vbox, gint first)
 			longrun.gkchart.chart);
   
 	k = gkrellm_create_krell(longrun.gkchart.chart->panel,
-			gkrellm_krell_panel_image(chart_style_id), style);
+			gkrellm_krell_panel_piximage(chart_style_id), style);
 
 	gkrellm_monotonic_krell_values(k, FALSE);
 	gkrellm_set_krell_full_scale(k, KRELL_MAX, 1);
 	gkrellm_panel_configure(longrun.gkchart.chart->panel,
 			g_strdup("LongRun"), style);
-	gkrellm_panel_create(vbox, longrun.gkchart.monitor,
+	gkrellm_panel_create(vbox, longrun.monitor,
 			longrun.gkchart.chart->panel);
 
 	if (!longrun.gkchart.enable) {
 		gkrellm_monitor_height_adjust(-longrun.gkchart.chart->panel->h);
 		gkrellm_monitor_height_adjust(-longrun.gkchart.chart->h);
 		gtk_widget_hide(longrun.gkchart.chart->panel->hbox);
-		gtk_widget_hide(longrun.gkchart.chart->hbox);
+		gtk_widget_hide(longrun.gkchart.chart->box);
 	}
   
 	if ( first ) {
@@ -387,7 +394,7 @@ create_gkrellongrun_chart(GtkWidget *vbox, gint first)
 static void
 create_gkrellongrun(GtkWidget *vbox, gint first)
 {
-	Style *style;
+	GkrellmStyle *style;
 	gint i;
 
 	style = gkrellm_meter_style( meter_style_id );
@@ -404,13 +411,13 @@ update_gkrellongrun_text(gint type)
 	gkrellm_draw_decal_text( longrun.parts[type].panel,
 			longrun.parts[type].decal,
 			longrun.parts[type].label, -1 );
-	gkrellm_draw_layers( longrun.parts[type].panel );
+	gkrellm_draw_panel_layers( longrun.parts[type].panel );
 }
 
 static void
 update_gkrellongrun()
 {
-	Krell *krell;
+	GkrellmKrell *krell;
 
 	if ( GK.second_tick ) {
 		gkrellm_store_chartdata(longrun.gkchart.chart, 0,
@@ -429,7 +436,7 @@ update_gkrellongrun()
 		gkrellm_update_krell( longrun.parts[Meter].panel,
 				longrun.parts[Meter].krell,
 				longrun.data[PercentageData]);
-		gkrellm_draw_layers( longrun.parts[Meter].panel );
+		gkrellm_draw_panel_layers( longrun.parts[Meter].panel );
 
 		set_slider_label();
 		longrun.parts[Slider].krell->previous = 0;
@@ -439,7 +446,7 @@ update_gkrellongrun()
 		gkrellm_draw_decal_text(longrun.parts[Slider].panel,
 			longrun.parts[Slider].decal,
 			longrun.parts[Slider].label, -1);
-		gkrellm_draw_layers(longrun.parts[Slider].panel);
+		gkrellm_draw_panel_layers(longrun.parts[Slider].panel);
 	}
 
 	krell = KRELL(longrun.gkchart.chart->panel);
@@ -480,28 +487,28 @@ create_gkrellongrun_tab(GtkWidget *tab)
 	gtk_box_pack_start(GTK_BOX(tab), tabs, TRUE, TRUE, 0);
 
 	/* Setup */
-	vbox = gkrellm_create_tab( tabs, _("Setup") );
+	vbox = gkrellm_gtk_framed_notebook_page( tabs, _("Setup") );
 
-	gkrellm_check_button( vbox, &longrun.parts[Mode].enable_button,
+	gkrellm_gtk_check_button( vbox, &longrun.parts[Mode].enable_button,
 			longrun.parts[Mode].enable, TRUE, 0, _("Enable mode") );
-	gkrellm_check_button( vbox, &longrun.parts[Frequency].enable_button,
+	gkrellm_gtk_check_button( vbox, &longrun.parts[Frequency].enable_button,
 			longrun.parts[Frequency].enable, TRUE, 0,
 			_("Enable frequency") );
-	gkrellm_check_button( vbox, &longrun.parts[Voltage].enable_button,
+	gkrellm_gtk_check_button( vbox, &longrun.parts[Voltage].enable_button,
 			longrun.parts[Voltage].enable, TRUE, 0,
 			_("Enable voltage") );
-	gkrellm_check_button( vbox, &longrun.parts[Meter].enable_button,
+	gkrellm_gtk_check_button( vbox, &longrun.parts[Meter].enable_button,
 			longrun.parts[Meter].enable, TRUE, 0,
 			_("Enable meter") );
-	gkrellm_check_button( vbox, &longrun.parts[Slider].enable_button,
+	gkrellm_gtk_check_button( vbox, &longrun.parts[Slider].enable_button,
 			longrun.parts[Slider].enable, TRUE, 0,
 			_("Enable slider") );
-	gkrellm_check_button( vbox, &longrun.gkchart.enable_button,
+	gkrellm_gtk_check_button( vbox, &longrun.gkchart.enable_button,
 			longrun.gkchart.enable, TRUE, 0,
 			_("Enable chart") );
 
 	/* Slider Setup */
-	vbox = gkrellm_create_tab(tabs, "Slider Setup");
+	vbox = gkrellm_gtk_framed_notebook_page(tabs, "Slider Setup");
 
 	for ( i = 0 ; i <= LongRunDataTypeNum ; i++ ) {
 		config_radio[i] = gtk_radio_button_new_with_label(label_group,
@@ -519,8 +526,9 @@ create_gkrellongrun_tab(GtkWidget *tab)
 	}
 
 	/* Chart Setup */
-	vbox = gkrellm_create_tab(tabs, "Chart Setup");
-	vbox1 = gkrellm_framed_vbox(vbox, _("Format String for Chart Labels"),
+	vbox = gkrellm_gtk_framed_notebook_page(tabs, "Chart Setup");
+	vbox1 = gkrellm_gtk_framed_vbox(vbox, 
+					_("Format String for Chart Labels"),
 					4, FALSE, 0, 2);
 	hbox = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, TRUE, 5);
@@ -537,15 +545,15 @@ create_gkrellongrun_tab(GtkWidget *tab)
 	gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(longrun.gkchart.text_format_combo)->entry), longrun.gkchart.text_format);
 
 	/* Infomation */
-	vbox = gkrellm_create_tab( tabs, _("Infomation") );
-	text = gkrellm_scrolled_text(vbox, NULL, GTK_POLICY_AUTOMATIC,
+	vbox = gkrellm_gtk_framed_notebook_page( tabs, _("Infomation") );
+	text = gkrellm_gtk_scrolled_text_view(vbox, NULL, GTK_POLICY_AUTOMATIC,
 					GTK_POLICY_AUTOMATIC);
 	for (i = 0; i < sizeof(gkrellongrun_info_text)/sizeof(gchar *); ++i)
-		gkrellm_add_info_text_string(text,
+		gkrellm_gtk_text_view_append(text,
 					_(gkrellongrun_info_text[i]));
 
 	/* About */
-	vbox = gkrellm_create_tab( tabs, _("About") );
+	vbox = gkrellm_gtk_framed_notebook_page( tabs, _("About") );
 	gkrellongrun_about_text = g_strdup_printf(
 		"%s %s\n" \
 		"GKrellM LongRun Plugin\n" \
@@ -573,7 +581,7 @@ apply_gkrellongrun_config()
 	gchar *s;
 	GKrelLongRunParts *p;
 
-	s = gkrellm_entry_get_text(&(GTK_COMBO(longrun.gkchart.text_format_combo)->entry));
+	s = gkrellm_gtk_entry_get_text(&(GTK_COMBO(longrun.gkchart.text_format_combo)->entry));
 	gkrellm_dup_string(&longrun.gkchart.text_format, s);
 
 	for ( i = 0 ; i < GKrelLongRunPartsTypeNum ; i++ ) {
@@ -614,14 +622,14 @@ apply_gkrellongrun_config()
 			gkrellm_monitor_height_adjust(
 				longrun.gkchart.chart->h);
 			gtk_widget_show(longrun.gkchart.chart->panel->hbox);
-			gtk_widget_show(longrun.gkchart.chart->hbox);
+			gtk_widget_show(longrun.gkchart.chart->box);
 		} else {
 			gkrellm_monitor_height_adjust(
 				-longrun.gkchart.chart->panel->h);
 			gkrellm_monitor_height_adjust(
 				-longrun.gkchart.chart->h);
 			gtk_widget_hide(longrun.gkchart.chart->panel->hbox);
-			gtk_widget_hide(longrun.gkchart.chart->hbox);
+			gtk_widget_hide(longrun.gkchart.chart->box);
 		}
 	}
 }
@@ -683,7 +691,7 @@ load_gkrellongrun_config(gchar *arg)
 						item, 1);
 }
 
-static Monitor gkrellongrun_mon  =
+static GkrellmMonitor gkrellongrun_mon  =
 {
 	"GKrelLongRun",			/* Name, for config tab. */
 	0,				/* Id, 0 if a plugin */
@@ -706,8 +714,8 @@ static Monitor gkrellongrun_mon  =
 	NULL			/* Path if a plugin, filled by GKrellM */
 };
 
-Monitor *
-init_plugin()
+GkrellmMonitor *
+gkrellm_init_plugin()
 {
 	int i;
 
@@ -717,7 +725,7 @@ init_plugin()
 	read_longrun_data();
 
 	gkrellongrun_factory = gkrellongrun_menu_factory();
-	longrun.gkchart.monitor = &gkrellongrun_mon;
+	longrun.monitor = &gkrellongrun_mon;
 	meter_style_id =
 		gkrellm_add_meter_style( &gkrellongrun_mon, GKRELLONGRUN );
 	chart_style_id =
