@@ -21,20 +21,17 @@ typedef enum {
 
 typedef struct {
         gint enable;
-        Panel *panel;
-        Decal *decal;
+        GkrellmPanel *panel;
+        GkrellmDecal *decal;
         gchar *label;
-        Krell *krell;
+        GkrellmKrell *krell;
         GtkWidget *enable_button;
 } GKrelLongRunParts;
 
 typedef struct {
         gint enable;
-	Display *display;
-	Window window;
-	Monitor *monitor;
-	Chart *chart;
-	ChartConfig *chart_config;
+	GkrellmChart *chart;
+	GkrellmChartconfig *chart_config;
 	gboolean draw_extra_info;
         GtkWidget *enable_button;
 	gchar *text_format;
@@ -42,6 +39,7 @@ typedef struct {
 } GKrelLongRunChart;
 
 struct _longrun_t {
+	GkrellmMonitor *monitor;
         GKrelLongRunParts parts[GKrelLongRunPartsTypeNum];
 	GKrelLongRunChart gkchart;
 	gint data[LongRunDataTypeNum];
